<?php

function ombutel_api_command($command, array $postdata) {
    global $OMBUTEL_KEY;
    $postdata['key'] = $OMBUTEL_KEY;
    $curl = curl_init();
    curl_setopt_array(
        $curl,
        array (
            CURLOPT_URL => "http://localhost/api/{$command}",
            CURLOPT_POST => true,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_POSTFIELDS => $postdata,
        )
    );
    $response = @json_decode(@curl_exec($curl));
    curl_close($curl);
    if (is_object($response) && isset($response->status)) {
        return $response;
    }
    return false;
}

function ombutel_authenticate_session($session_id) {
    return ombutel_authenticate(array( 'session_id' => $session_id ));
}

function ombutel_authenticate_user($username, $password) {
    return ombutel_authenticate(array( 'username' => $username, 'password' => $password ));
}

function ombutel_is_admin($token, $user_id) {
    if (is_object($result = ombutel_api_command("user/{$user_id}", ['token' => $token]))) {
        return ($result->data->role_id == 1); // dumb but works
    }
    return false;
}

function ombutel_authenticate(array $postdata) {
    // Used by both GUI and admin/update_conf.php!
    if ($result = ombutel_api_command('authenticate', $postdata)) {
        if ($result->status == 'success' && isset($result->data->token)) {
            if (isset($result->data->user_id)) {
                return [ $result->data->token, $result->data->user_id ];
            }
            return $result->data->token;
        }
     }
     return false;
 }

function isLoggedIn(){
    global $config_engine;

    if($config_engine=='freepbx' && USE_FREEPBX_AUTH==true) {
        if(isset($_SESSION['AMP_user'])) {
            return true;
        }
    }

    if ($config_engine == 'ombutel') {
        if (isset($_COOKIE['sid'])) {
            if ($result = ombutel_authenticate_session($_COOKIE['sid'])) {
                list($token, $user_id) = $result;
                return ombutel_is_admin($token, $user_id);
            }
        }
        return false;
    }

    if(is_file("/etc/elastix.conf")) {
        if(isset($_SESSION['elastix_user']) && USE_FREEPBX_AUTH==true) {
            return true;
        }
    }

    if(isset($_SESSION[MYAP]['AUTHVAR']["loggedIn"]) && $_SESSION[MYAP]['AUTHVAR']["loggedIn"] == 1 ){
        return true;
    } else {
        return false;
    }
}

function checkPass($login, $password) {

    global $db, $config_engine, $conf, $ADMINUSER, $ADMINPWD;

    if($config_engine=='freepbx' && USE_FREEPBX_AUTH==true) {

        $query="SELECT username AS login,IF(sections='*','admin','user') AS level,username AS name FROM ".$conf['DBNAME'].".ampusers WHERE username='%s' AND password_sha1=sha1('%s')";

        $res=$db->consulta($query,Array($login,$password));

        if($db->num_rows($res)==1) {
            $row = $db->fetch_assoc($result);
            $row['ok']=1;
        } else {
            $row['error']=__('Invalid Credentials');
        }

    } else if ($config_engine == 'ombutel') {
        if ($result = ombutel_authenticate_user($login, $password)) {
            list($token, $user_id) = $result;
            if (ombutel_is_admin($token, $user_id)) {
                @session_destroy();
                session_name('sid');
                session_id($token);
                @session_start();
                return array( 'ok' => 1 );
            }
        }
        return array ( 'error' => __('Invalid Credentials') );
    } else {
        if($login==$ADMINUSER && $password==$ADMINPWD) {
            $row['ok']=1;
        } else {
            $row['error']=__('Invalid Credentials');
        }
    }
    return $row;
}

function initSession($row) {
    $_SESSION[MYAP]['AUTHVAR']["loggedIn"] = true;
    $_SESSION[MYAP]['AUTHVAR']["ip"] = $_SERVER['REMOTE_ADDR'];
}

function flushSession() {
    unset($_SESSION[MYAP]["AUTHVAR"]);
    unset($_COOKIE['context']);
    setcookie("context", "0", time()-3600);
    setcookie(session_name(), null, -1, '/');
    @session_destroy();
    return true;
}

